@@ -9,9 +9,16 @@ _logger = logging.getLogger(__name__)
 
 
 class Sql:
-
+    """
+    Class that contains all of the SQL to execute
+    """
     @staticmethod
     def build_columns_query(table_schema_name, table_name):
+        """
+        Query that gets all columns by schema and table names
+        :return: query string
+        :rtype: str
+        """
         return """select
         table_schema,
         table_name,
@@ -28,6 +35,11 @@ class Sql:
 
     @staticmethod
     def build_tables_query(table_schema_name):
+        """
+        Query that gets all table schema based off table schem.
+        :return: query string
+        :rtype: str
+        """
         return """select
             table_schema,
             table_name,
@@ -39,6 +51,11 @@ class Sql:
 
     @staticmethod
     def build_insertion_table_order():
+        """
+        Query that gets the insertion order of the database
+        :return: query string
+        :rtype: str
+        """
         return """WITH RECURSIVE fkeys AS (
                     SELECT conrelid AS source,
                            confrelid AS target
@@ -87,6 +104,11 @@ class Sql:
 
     @staticmethod
     def build_column_constraints(table_schema_name, table_name, column_name):
+        """
+        Query that gets the column constraints
+        :return: query string
+        :rtype: str
+        """
         return """select
             coalesce(table_schema, referenced_schema) as table_schema,
             coalesce(table_name, referenced_table) as table_name,
@@ -117,22 +139,41 @@ class Sql:
 
     @staticmethod
     def build_values_from_type(type):
+        """
+        Query that gets values from type
+        :return: query string
+        :rtype: str
+        """
         return """SELECT pg_type.typname AS enumtype,
                pg_enum.enumlabel AS enumlabel
         FROM pg_type
                  JOIN pg_enum
                       ON pg_enum.enumtypid = pg_type.oid
-        WHERE pg_type.typname = '{type}'
- """.format(type=type)
+        WHERE pg_type.typname = '{type}'""".format(type=type)
 
     @staticmethod
     def build_populate_insert(table_name, columns):
+        """
+         Query that inserts table data
+         :return: query string
+         :rtype: str
+         """
         return """INSERT INTO "{table_name}"({columns} ) VALUES %s ON CONFLICT DO NOTHING""".format(table_name=table_name, columns=columns)
 
     @staticmethod
     def build_random_row(columns, table):
+        """
+        Query that gets a random row from a table
+        :return: query string
+        :rtype: str
+        """
         return "SELECT {columns} FROM {table} ORDER BY random() LIMIT 1".format(columns=columns, table=table)
 
     @staticmethod
     def build_random_row_where(columns, table, query):
+        """
+        Query that gets random row from a table with a where statement
+        :return: query string
+        :rtype: str
+        """
         return "SELECT {columns} FROM {table} {query} ORDER BY random() LIMIT 1".format(columns=columns, table=table, query=query)
